@@ -38,8 +38,8 @@ class Storage(driver.Base):
         if len(mpath) == 0:
             return
 
-        parts = mpath.split('/')
-        mpath = '/'.join(parts[0: 3])
+        parts = mpath.split('/')[len(self.config.path.split('/')):]
+        mpath = self.config.path
 
         for part in parts[3:]:
             mpath += '/' + part
